@@ -1,3 +1,4 @@
+{-# OPTIONS_GHC -Wno-deprecations #-}
 {-# language OverloadedStrings #-}
 module Main where
 
@@ -45,5 +46,13 @@ main =
         prop_reverse_involutive
     , expectFail $ testProperty
         "badReverse involutive fails"
-         prop_badReverse_involutive
+        prop_badReverse_involutive
+    , testPropertyNamed
+        "reverse involutive"
+        "prop_reverse_involutive"
+        prop_reverse_involutive
+    , expectFail $ testPropertyNamed
+        "badReverse involutive fails"
+        "prop_badReverse_involutive"
+        prop_badReverse_involutive
     ]
